"""Top-level package for Altair Express."""

__author__ = """Dylan Wootton"""
__email__ = 'dwootton@mit.edu'
__version__ = '0.1.20'

from .relational.joint_plot import *
from .pair_plot import *
from .distributional import *
from .relational.relational import *
from .data_table import *
from .interactions import *